@@ -14,7 +14,6 @@ byComplexity <- function(x, model)
            },
            hda =
            {
-             
              x[order(x$newdim, -x$lambda, x$gamma),] 
            },           
            gbm =
@@ -166,6 +165,10 @@ byComplexity <- function(x, model)
            {
              x[order(x$nt),]
            },
+           cubist =
+           {
+             x[order(x$committees,  x$neighbors),]
+           },
            logreg = x[order(x$ntrees, x$treesize),],
            logicBag = x[order(x$ntrees, x$nleaves),],
            neuralnet = x[order(x$layer1, x$layer2, x$layer3),],
